@@ -71,7 +71,7 @@ enum wxAuiManagerOption
 
     wxAuiManager is the central class of the wxAUI class framework.
 
-    wxAuiManager manages the panes associated with it for a particular wxFrame,
+    wxAuiManager manages the panes associated with it for a particular window,
     using a pane's wxAuiPaneInfo information to determine each pane's docking
     and floating behaviour.
 
@@ -87,18 +87,18 @@ enum wxAuiManagerOption
     flicker, by modifying more than one pane at a time, and then "committing"
     all of the changes at once by calling Update().
 
-    Panes can be added quite easily:
+    Panes can be added using AddPane():
 
     @code
-    wxTextCtrl* text1 = new wxTextCtrl(this, -1);
-    wxTextCtrl* text2 = new wxTextCtrl(this, -1);
+    wxTextCtrl* text1 = new wxTextCtrl(this, wxID_ANY);
+    wxTextCtrl* text2 = new wxTextCtrl(this, wxID_ANY);
     m_mgr.AddPane(text1, wxLEFT, "Pane Caption");
     m_mgr.AddPane(text2, wxBOTTOM, "Pane Caption");
     m_mgr.Update();
     @endcode
 
-    Later on, the positions can be modified easily. The following will float
-    an existing pane in a tool window:
+    Later on, the positions and other attributes can be modified, e.g. the
+    following will float an existing pane in a tool window:
 
     @code
     m_mgr.GetPane(text1).Float();
@@ -197,13 +197,14 @@ public:
     /**
         Constructor.
 
-        @param managed_wnd
-            Specifies the wxFrame which should be managed.
+        @param managedWindow
+            Specifies the window which will contain AUI panes. If it is not
+            specified here, it must be set later using SetManagedWindow().
         @param flags
             Specifies the frame management behaviour and visual effects
             with the ::wxAuiManagerOption's style flags.
     */
-    wxAuiManager(wxWindow* managed_wnd = nullptr,
+    wxAuiManager(wxWindow* managedWindow = nullptr,
                  unsigned int flags = wxAUI_MGR_DEFAULT);
 
     /**
@@ -543,11 +544,17 @@ public:
     void SetFlags(unsigned int flags);
 
     /**
-        Called to specify the frame or window which is to be managed by wxAuiManager.
-        Frame management is not restricted to just frames.  Child windows or custom
-        controls are also allowed.
+        Set the window which is to be managed by wxAuiManager.
+
+        This window will often be a wxFrame but an arbitrary child window can
+        also be used.
+
+        Note that wxAuiManager handles many events for the managed window,
+        including ::wxEVT_SIZE, so any application-defined handlers for this
+        window should take care to call wxEvent::Skip() to let wxAuiManager
+        perform its own processing.
     */
-    void SetManagedWindow(wxWindow* managed_wnd);
+    void SetManagedWindow(wxWindow* managedWindow);
 
     /**
         This function is used to show a hint window at the specified rectangle.
@@ -765,11 +772,29 @@ public:
     //@{
     /**
         FloatingSize() sets the size of the floating pane.
+
+        FloatingClientSize() has precedence over this, i.e. this size is ignored
+        if the floating client size is specified.
     */
     wxAuiPaneInfo& FloatingSize(const wxSize& size);
     wxAuiPaneInfo& FloatingSize(int x, int y);
     //@}
 
+    //@{
+    /**
+        FloatingClientSize() sets the client size of the floating pane.
+
+        This has precedence over FloatingSize(), i.e. FloatingSize() is ignored
+        if this is specified.
+
+        @see wxWindow::SetClientSize
+
+        @since 3.3.1
+    */
+    wxAuiPaneInfo& FloatingClientSize(const wxSize& size);
+    wxAuiPaneInfo& FloatingClientSize(int x, int y);
+    //@}
+
     /**
         Gripper() indicates that a gripper should be drawn for the pane.
     */
